Module convert

Module convert 

Pixel format conversion utilities.

These are opt-in and allocate a new FrameEnvelope. They are not used on the hot path — stages that need a specific format should convert explicitly.

Enums

ConvertError
Errors from convert().

Functions

convert
Convert a frame to a different pixel format.